==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__241.h <==
// final class javax.swing.plaf.basic.BasicOptionPaneUI$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dfddd3794f21401 javax_swing_plaf_basic_BasicOptionPaneUI__241
// @dep_class 7173f5e939a87bd6 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

#include "javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods {
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__241;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__241.h <==
// final class javax.swing.plaf.basic.BasicOptionPaneUI$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 185906e7c161f58b javax_swing_plaf_basic_BasicOptionPaneUI__241
// @dep_class dfbd93626158fee3 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

#include "javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods {
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__241;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__241;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__241;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__241_H_ */
